@@ -31,8 +31,8 @@
 #ifndef INN_XWRITE_H
 #define INN_XWRITE_H 1
 
-#include <inn/defines.h>
 #include "inn/portable-macros.h"
+#include "inn/system.h"
 
 #include <sys/types.h>
 
