@@ -21,10 +21,10 @@
 
 #include "config.h"
 #include "portable/socket.h"
-#include "clibrary.h"
+#include "portable/system.h"
 
-#include "tap/basic.h"
 #include "inn/xmalloc.h"
+#include "tap/basic.h"
 
 int test_getnameinfo(const struct sockaddr *, socklen_t, char *, socklen_t,
                      char *, socklen_t, int);
