@@ -34,17 +34,17 @@
 
 #include "config.h"
 #include "portable/socket.h"
-#include "clibrary.h"
+#include "portable/system.h"
 
 #include <errno.h>
 #include <signal.h>
 #include <sys/wait.h>
 
-#include "tap/basic.h"
 #include "inn/fdflag.h"
 #include "inn/macros.h"
 #include "inn/messages.h"
 #include "inn/network.h"
+#include "tap/basic.h"
 
 
 /*
